VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "clsPrintLinesV2"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
' Module     : clsPrintLinesV2V2
' Description:
' Procedures : InitSections(rpt As Report, lngLineBorderwidth As Long)
'              ResetToDefaults()
'              Get LineBorderWidthDefault()
'              Let LineBorderWidthDefault(lb As Integer)
'              Get MaxSection()
'              Get plSection(intSectionNum As Integer)
'              Get SelectControlsMode()
'              Let SelectControlsMode(fSelectCtls As Boolean)
'              Class_Initialize()
'              Class_Terminate()

' Modified   :
' 01/23/02 S Cleaned with Total Visual CodeTools 2000
'
' --------------------------------------------------
Option Compare Database
Option Explicit

'Name                   clsPrintLinesV2SMD
'
'Purpose:               Contains functionality to allow for
'                       simple selection of Vertical Lines
'                       and Borders for each Section of a Report.
'
'Version:               3.0
'
'Calls:                 Uses the Line method of the Report object
'                       to draw lines, borders and boxes. No API's,
'                       just the plain old Report object and VBA. :)
'
'Returns:               Nothing.
'
'INPUTS:                Every Section in the Report must have at least
'                       one Control in it. The control does not have to
'                       be visible!!!
'
'Created by:            Stephen Lebans
'
'Credits:               Anybody who wants some..go ahead!<grin>
'
'Date:                  August 13, 2000
'
'Time:                  1:22:12 pm
'
'Feedback:              Stephen@lebans.com
'
'My Web Page:           www.lebans.com
'
'Copyright:             Lebans Holdings 1999 Ltd.
'                       Please feel free to use this code
'                       without restriction in any application you develop,
'                       whether private or commercial.
'                       This code may not be resold by itself or as
'                       part of a collection.
'
'
'Bugs:                  The following KB article explains why I cannot directly
'                       set a Reference to a Report object itself in this
'                       Class. To avoid all of the hoops we would have to jump through
'                       to code a solution I have opted to simply
'                       only sink events at the Report Section level.
'                       To get the required reference back to the main
'                       Report object we simply use the Section.Parent property.
'http://support.microsoft.com/support/kb/articles/Q223/2/45.ASP?LN=EN-US&SD=gn&FR=0


'Not tested enough to tell. Let me know
'NEEDS MORE ERROR HANDLING
'
'What's Missing:        A nice GUI to set all of these PROPERTIES!!!
'                       A GRID property. It would just need to draw a
'                       vertical line in the Page Footer up to the
'                       very last row of the Detail Section.
'                       THis is required if the Detail KeepTogether
'                       prop is set to YES. THe situation also occurs
'                       when there is not enough space between the last
'                       drawn row of the Detail Section and the start of
'                       Page Footer for the hight of one complete
'                       row of the Detail Section. I'll add this in the
'                       next release.
'
'Enjoy
'Stephen Lebans
'
'   Revisions by Sandra Daigle
'
'   General - added error handling :-)
'
'           - Note that if you use error handling in the report class module that
'             calls this code and you refer to a section that does not exist in the report,
'             you will get runtime errors - without going to a lot of extra trouble, I don't
'             know a way to check this at compile time.
'
'           - Also added a wrapper procedure that includes a function to return a
'             new instance of the main class, clsPrintLinesV2SMD - this makes it easier to
'             reference these classes from a library mdb. Granted, there are different
'             ways to go about this, this one is fool proof. I personally have had trouble
'             with the Export/Edit Attributes/Import module technique. I've run into
'             situations in which the attributes were stripped anyway so I no longer
'             rely on them.
'
'   Changed the child class "clsSectionProperties" to "clsPLSection". The new
'   class now includes the properties of the section and the section object that is
'   declared using With Events. Consequently, there is only one set of Section
'   event procedures.'
'
'   The workhouse procedures, Draw, DrawVertical and DrawBorders are now in the child class
'
'   Add a few formatting options, these are available as properties of clsPLSection:
'       LeftBorderPosition, RightBorderPosition - allow you to specify specific positions for
'           the left and right edges of the border. If these properties are not set,
'           the default is still to go the full page width.
'       SelectControlsMode - this is a boolean property. The default is false. When set to true,
'           Vertical lines are drawn to the right of only the controls that have the
'           text 'VerticalLine' in the tag property. Use this option if you want vertical lines
'           for only a few controls.
'
'           Conversely, to selectively disable the vertical line, you can put 'NoVertical'
'           in the tag. In this case the SelectControlsMode property should be false.
'
'   What was originally the Section Property of clsSectionProperties has been renamed to
'       plSection. This may not have been necessary but it helped to clarify references.
'
'
'   The main class, clsPrintLinesV2SMD now builds a collection of clsPLSections based on which
'   sections actually exist in the report. clsPLSection will create one of
'   the following:
'
'   Private WithEvents mSection  As Access.[_SectionInReport]
'   Private WithEvents mSectionPageHeader As Access.[_PageHdrFtrInReport]
'   Private WithEvents mSectionPageFooter As Access.[_PageHdrFtrInReport]
'
'   I never would have figured out the specialized classes for page header/footer
'   I still wonder how Stephen found out about them.
'
'   The main class does not have to discriminate between the page header/footer and the
'   other report sections. This is all now handled via the member class.
'
' *** CODE START ****


' Grab the events we are interested in
' raised by this Report.
' We are unable to simply pass and hold
' a reference to the Report object itself. There is a
' documented bug that causes a GPF when you try to
' release this reference.

' So instead of doing something like the following:
'Public WithEvents mReport As Access.Report
'Dim mReport As Access.Report
' instead we have to set references to the Report's Sections.
' Through these references we can sink the required events
' for each section and also refer back to the main Report
' via the Section's parent propert.


' Here are the general declarations required for us
' to grab the events raised by each Section.
' You need to specify the hidden
' object Type of _SectionInReport as this interfaces
' with the Sections on a Report where the standard
' Section pertains to Forms. You can see this by browsing
' the Access Type Library or simply go into the
' Object Browser and Right Click the mouse to select
' the "Show Hidden Members" dropdown menu.
' We need to add a declaration for each seperate Section
' that you want to interact with. For this Demo we will
' be using a Report with the following Sections.
' Report Header
' Page Header
' Detail
' Group Header
' Group Footer
' Page Footer
' Report Footer
Private mcolSections As Collection

' Default setting for Report DrawWidth property.
' This property contains the default value for the
' line thickness in device pixels.
Private mintLineBorderWidthDefault As Integer

' Line Margin for Vertical Lines.
' We will start our Vertical Lines this
' many TWIPS to the Right of the edge of the control.
Private mintVerticalLineMargin As Integer

Private Type mtypPrtMipsTemp
    strMips As String * 28
End Type

' Printer MIPS Structure
Private Type mtypPrinterMips
    lngLeft As Long
    lngTop As Long
    lngRight As Long
    lngBottom As Long
    lngDataOnly As Long
    lngWidth As Long
    lngHeight As Long
    lngDefaultSize As Long
    lngItemsAcross As Long
    lngColumnSpacing As Long
    lngRowSpacing As Long
    lngItemLayout As Long
    lngFastPrinting As Long
    lngDataSheet As Long
End Type

' Track where Detail Section Ends
' so we can Draw Grid to fill in
' down the rest of the page
' Not use in this release
'Dim intDetailEnds As Integer

' All report props relating to measurement
' are expressed in TWIPS.
' Number of TWIPS PER INCH
Const mcTWIPSPERINCH = 1440


Private Const mcstrModule As String = "clsPrintLinesV2"
Private mfSelectControlsMode As Boolean
Private mobjSections As Object
Private mobjSection As Object
Private mintMaxSectionNum As Integer
Private mlngSection As Long
Private mlngVerticalLineMargin As Long
Private mfBorder As Boolean
Private mintBorderWidth As Integer
Private mintVerticalLines As Integer
Private mfVerticalLines As Boolean
Private mintVerticalLinesWidth As Integer
Private mlngBorderColor As Long
Private mlngVerticalLinesColor As Long
Private mintBorderDrawMode As Integer
Private mintBorderDrawStyle As Integer
Private mintVerticallinesDrawMode As Integer
Private mintVerticalLinesDrawStyle As Integer

Public Sub InitSections(rpt As Report)
    ' Comments  :
    ' Parameters: rpt
    '             lngLineBorderwidth -
    ' Modified  :
    '
    ' --------------------------------------------------
    ' This is the main initialization
    ' routine for this SUB. It must be called directly
    ' from the Report.
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    
    Dim curPLSection As clsPLSection
    Dim curSection As Section
    Dim intI As Integer
    Dim strX As String
    Dim fDone As Boolean
    Dim ctl As Control
    Dim strKey As String
    Dim lngMaxSections As Long
    ' Need to catch if we are here because we are trying
    ' to release our Class on Report Close event.
    If rpt Is Nothing Then
        Exit Sub
    End If
    
    ' Set the references to each Section in the Report
    ' We are currently only using the Print event
    ' but I do have plans to use the Format event
    ' in the next release. I'm leaving in the init
    ' code for the Format event but commenting it out
    ' for this release.
    Set mcolSections = New Collection
    intI = 0
    
    lngMaxSections = 0
    For Each ctl In rpt
        If ctl.Section > lngMaxSections Then
            lngMaxSections = ctl.Section
        End If
    Next ctl
    Set ctl = Nothing
    
    
    
    Do Until intI > lngMaxSections
        On Error Resume Next
        strX = rpt.Section(intI).name
        If Err.Number = 0 Then
            On Error GoTo Proc_Err
            Set curSection = rpt.Section(intI)
            If Not curSection Is Nothing Then
                Set curPLSection = New clsPLSection
                curPLSection.InitSection curSection, Me, intI
                strKey = "S" & intI
                mcolSections.Add curPLSection, strKey
            End If
        Else
            On Error GoTo Proc_Err
        End If
        intI = intI + 1
    Loop
    mintMaxSectionNum = intI - 1
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Sub
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "InitSections", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Sub

Public Sub ResetAll()
    ' Comments  :
    ' Parameters:  -
    ' Modified  :
    '
    ' --------------------------------------------------
    ' Let's turn all of the props ON!
    '
    'SectionDetailBorder = True
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    
    Dim intI As Integer
    Dim curPLSection As clsPLSection
    If Not mcolSections Is Nothing Then
        For intI = 1 To mcolSections.Count
            Set curPLSection = mcolSections(intI)
            With curPLSection
                .Border = mfBorder
                .BorderWidth = mintLineBorderWidthDefault
                .LineBorderWidthDefault = mintLineBorderWidthDefault
                .VerticalLines = mfVerticalLines
                .VerticalLinesWidth = mintLineBorderWidthDefault
                .VerticalLineMargin = mintVerticalLineMargin
                .BorderColor = mlngBorderColor
                .VerticalLinesColor = mlngVerticalLinesColor
                .BorderDrawMode = mintBorderDrawMode
                .BorderDrawStyle = mintBorderDrawStyle
                .VerticallinesDrawMode = mintVerticallinesDrawMode
                .VerticalLinesDrawStyle = mintVerticalLinesDrawStyle
            End With
        Next intI
    End If
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Sub
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "ResetAll", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Sub

Public Sub ResetToDefaults()
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 10:58 S
    ' Modified  :
    '
    ' --------------------------------------------------
    
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mfBorder = True
    mintBorderWidth = 6
    mintLineBorderWidthDefault = 4
    mfVerticalLines = True
    mintVerticalLinesWidth = 6
    mintVerticalLineMargin = 60
    mlngBorderColor = RGB(0, 0, 0)
    mlngVerticalLinesColor = RGB(0, 0, 0)
    mintBorderDrawMode = 13
    mintBorderDrawStyle = 0
    mintVerticallinesDrawMode = 2
    mintVerticalLinesDrawStyle = 0
    ResetAll
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Sub
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "ResetToDefaults", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Sub

Public Property Get Border() As Boolean
    ' Comments  :
    ' Parameters:
    ' Returns   : Boolean
    ' Created   : 01/25/02 11:01 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    Border = mfBorder
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "Border", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let Border(fBorder As Boolean)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:01 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mfBorder = fBorder
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "Border", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get BorderColor() As Long
    ' Comments  :
    ' Parameters:
    ' Returns   : Long
    ' Created   : 01/25/02 11:07 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    BorderColor = mlngBorderColor
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderColor", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let BorderColor(lngBorderColor As Long)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:07 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mlngBorderColor = lngBorderColor
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderColor", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get BorderDrawMode() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Integer
    ' Created   : 01/25/02 11:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    BorderDrawMode = mintBorderDrawMode
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderDrawMode", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let BorderDrawMode(intBorderDrawMode As Integer)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mintBorderDrawMode = intBorderDrawMode
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderDrawMode", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get BorderDrawStyle() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Integer
    ' Created   : 01/25/02 11:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    BorderDrawStyle = mintBorderDrawStyle
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderDrawStyle", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let BorderDrawStyle(intBorderDrawMode As Integer)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mintBorderDrawStyle = intBorderDrawMode
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderDrawStyle", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get BorderWidth() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Integer
    ' Created   : 01/25/02 11:01 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    BorderWidth = mintBorderWidth
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderWidth", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let BorderWidth(intBorderWidth As Integer)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:01 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mintBorderWidth = intBorderWidth
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "BorderWidth", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get LineBorderWidthDefault() As Integer
    ' Comments  :
    ' Parameters:  -
    ' Returns   : Integer
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    
    LineBorderWidthDefault = mintLineBorderWidthDefault
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "LineBorderWidthDefault", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Property

Public Property Let LineBorderWidthDefault(lb As Integer)
    ' Comments  :
    ' Parameters: lb -
    ' Modified  :
    '
    ' --------------------------------------------------
    ' Default setting for Report DrawWidth property.
    ' This property contains the default value for the
    ' line thickness in device pixels.
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    
    mintLineBorderWidthDefault = lb
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "LineBorderWidthDefault", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Property

Public Property Get MaxSectionNum() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Long
    ' Created   : 01/22/02 12:53 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    MaxSectionNum = mintMaxSectionNum
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "MaxSectionNum", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get plSection(intSectionNum As Integer) As clsPLSection
    ' Comments  :
    ' Parameters:
    ' Returns   : Long
    ' Created   : 01/22/02 14:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    Dim strKey As String
    strKey = "S" & intSectionNum
    If SectionExists(intSectionNum) Then
        Set plSection = mcolSections.Item(strKey)
    Else
        Set plSection = Nothing
    End If
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "plSection", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get SelectControlsMode() As Boolean
    ' Comments  :
    ' Parameters:
    ' Returns   : Boolean
    ' Created   : 09/21/01 16:09 SMD
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    SelectControlsMode = mfSelectControlsMode
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "SelectControlsMode", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let SelectControlsMode(fSelectCtls As Boolean)
    ' Comments  :
    ' Parameters:
    ' Created   : 09/21/01 16:09 SMD
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mfSelectControlsMode = fSelectCtls
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "SelectControlsMode", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get VerticalLineMargin() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Long
    ' Created   : 01/24/02 11:46 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    VerticalLineMargin = mintVerticalLineMargin
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLineMargin", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let VerticalLineMargin(intVerticalLineMargin As Integer)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/24/02 11:46 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mintVerticalLineMargin = intVerticalLineMargin
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLineMargin", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get VerticalLines() As Boolean
    ' Comments  :
    ' Parameters:
    ' Returns   : Boolean
    ' Created   : 01/25/02 11:06 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    VerticalLines = mfVerticalLines
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLines", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let VerticalLines(fVerticalLines As Boolean)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:06 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mfVerticalLines = fVerticalLines
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLines", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get VerticalLinesColor() As Long
    ' Comments  :
    ' Parameters:
    ' Returns   : Long
    ' Created   : 01/25/02 11:07 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    VerticalLinesColor = mlngVerticalLinesColor
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLinesColor", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let VerticalLinesColor(lngVerticalLinesColor As Long)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:07 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mlngVerticalLinesColor = lngVerticalLinesColor
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLinesColor", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get VerticallinesDrawMode() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Integer
    ' Created   : 01/25/02 11:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    VerticallinesDrawMode = mintVerticallinesDrawMode
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticallinesDrawMode", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let VerticallinesDrawMode(intVerticallinesDrawMode As Integer)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mintVerticallinesDrawMode = intVerticallinesDrawMode
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticallinesDrawMode", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get VerticalLinesDrawStyle() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Integer
    ' Created   : 01/25/02 11:09 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    VerticalLinesDrawStyle = mintVerticalLinesDrawStyle
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLinesDrawStyle", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let VerticalLinesDrawStyle(intVerticalLinesDrawStyle As Integer)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:09 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mintVerticalLinesDrawStyle = intVerticalLinesDrawStyle
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLinesDrawStyle", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Get VerticalLinesWidth() As Integer
    ' Comments  :
    ' Parameters:
    ' Returns   : Integer
    ' Created   : 01/25/02 11:06 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    VerticalLinesWidth = mintVerticalLinesWidth
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLinesWidth", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Public Property Let VerticalLinesWidth(intVerticalLinesWidth As Integer)
    ' Comments  :
    ' Parameters:
    ' Created   : 01/25/02 11:06 S
    ' Modified  :
    '
    ' --------------------------------------------------
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    mintVerticalLinesWidth = intVerticalLinesWidth
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Property
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "VerticalLinesWidth", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
End Property

Private Sub Class_Initialize()
    ' Comments  :
    ' Parameters:  -
    ' Modified  :
    '
    ' --------------------------------------------------
    
    ' Set default Draw Width property for all lines
    ' draw for Borders.
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    
    ResetToDefaults
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Sub
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "Class_Initialize", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Sub

Private Sub Class_Terminate()
    ' Comments  :
    ' Parameters:  -
    ' Modified  :
    '
    ' --------------------------------------------------
    ' Add cleanup routine here!
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    Set mcolSections = Nothing
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Sub
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "Class_Terminate", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Sub

Private Function SectionExists(pIntSectionNum As Integer) As Boolean
    ' Comments  :
    ' Parameters:
    ' Returns   : Boolean -
    ' Created   : 01/24/02 11:08 S
    ' Modified  :
    '
    ' --------------------------------------------------
    
    'TVCodeTools ErrorEnablerStart
    On Error GoTo Proc_Err
    'TVCodeTools ErrorEnablerEnd
    Dim strKey As String
    Dim strX As String
    strKey = "S" & pIntSectionNum
    On Error Resume Next
    strX = mcolSections.Item(strKey).SectionName
    SectionExists = Err.Number = 0
    
    
    'TVCodeTools ErrorHandlerStart
Proc_Exit:
    Exit Function
    
Proc_Err:
    Select Case Err.Number
        Case Else
            Select Case ErrorDisplay(Err.Number, Error$, mcstrModule, "SectionExists", Erl())
                Case errContinue
                    Resume Next
                Case errexit
                    Resume Proc_Exit
            End Select
    End Select
    'TVCodeTools ErrorHandlerEnd
    
End Function

